# This is an auto-generated file, please do not modify

QUERIES = {'byauthorsorted': '\n  query ByAuthorSorted(\n    $author: String\n    $updatedAt: ModelStringKeyConditionInput\n    $sortDirection: ModelSortDirection\n    $filter: ModelAllRunbooksFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    byAuthorSorted(\n      author: $author\n      updatedAt: $updatedAt\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        name\n        description\n        content\n        author\n        commands\n        createdAt\n        updatedAt\n        RunBookConnectors\n        type\n        longSave\n        rbVars\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      nextToken\n    }\n  }\n',
 'byinvsorted': '\n  query ByInvSorted(\n    $investigationId: ID\n    $updatedAt: ModelStringKeyConditionInput\n    $sortDirection: ModelSortDirection\n    $filter: ModelInvestigationEventFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    byInvSorted(\n      investigationId: $investigationId\n      updatedAt: $updatedAt\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        author\n        content\n        type\n        links\n        investigationId\n      }\n      nextToken\n    }\n  }\n',
 'epicbyibid': '\n  query EpicByIbid(\n    $investigationId: ID\n    $sortDirection: ModelSortDirection\n    $filter: ModelepicAutoCompleteFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    epicByIBID(\n      investigationId: $investigationId\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        author\n        cliCommand\n        command\n        createdAt\n        updatedAt\n        investigationId\n        times\n      }\n      nextToken\n    }\n  }\n',
 'getallrunbooks': '\n  query GetAllRunbooks($id: ID!) {\n    getAllRunbooks(id: $id) {\n      id\n      name\n      description\n      content\n      author\n      commands\n      createdAt\n      updatedAt\n      RunBookConnectors\n      type\n      longSave\n      rbVars\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n      connectorForms {\n        nextToken\n      }\n    }\n  }\n',
 'getallworkflows': '\n  query GetAllWorkflows($id: ID!) {\n    getAllWorkflows(id: $id) {\n      id\n      createdAt\n      updatedAt\n      name\n      description\n      type\n      author\n      longSave\n      rbVars\n    }\n  }\n',
 'getchannel': '\n  query GetChannel($id: ID!) {\n    getChannel(id: $id) {\n      id\n      messages {\n        nextToken\n      }\n      associated {\n        nextToken\n      }\n      name\n      title\n      members\n      membersState\n      createdAt\n      updatedAt\n      memberLocation\n    }\n  }\n',
 'getchannellink': '\n  query GetChannelLink($id: ID!) {\n    getChannelLink(id: $id) {\n      id\n      contactId\n      channel {\n        id\n        name\n        title\n        members\n        membersState\n        createdAt\n        updatedAt\n        memberLocation\n      }\n      chatId\n      unread\n      createdAt\n      updatedAt\n      user {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n    }\n  }\n',
 'getchat': '\n  query GetChat($id: ID!) {\n    getChat(id: $id) {\n      id\n      from\n      content\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getcheatsheet': '\n  query GetCheatSheet($id: ID!) {\n    getCheatSheet(id: $id) {\n      id\n      createdAt\n      updatedAt\n      title\n      author\n      content\n      type\n    }\n  }\n',
 'getchecklist': '\n  query GetCheckList($id: ID!) {\n    getCheckList(id: $id) {\n      id\n      createdAt\n      updatedAt\n      name\n      description\n      type\n      content\n      author\n      CheckListLink {\n        nextToken\n      }\n      CheckListInvLink {\n        nextToken\n      }\n    }\n  }\n',
 'getchecklistinvlink': '\n  query GetCheckListInvLink($id: ID!) {\n    getCheckListInvLink(id: $id) {\n      id\n      createdAt\n      updatedAt\n      investigationID\n      CheckListID\n      CheckList {\n        id\n        createdAt\n        updatedAt\n        name\n        description\n        type\n        content\n        author\n      }\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      owner\n    }\n  }\n',
 'getchecklistitem': '\n  query GetCheckListItem($id: ID!) {\n    getCheckListItem(id: $id) {\n      id\n      localID\n      createdAt\n      updatedAt\n      author\n      content\n      title\n      type\n      connection\n      MMNodeConnection\n      investigationID\n      assignee\n      associatedPlaybooks\n      associatedCommands\n      CheckListLink {\n        nextToken\n      }\n    }\n  }\n',
 'getclick': '\n  query GetClick($id: ID!) {\n    getClick(id: $id) {\n      id\n      count\n      type\n      featureName\n      createdAt\n      updatedAt\n      readAt\n    }\n  }\n',
 'getclicllink': '\n  query GetCliclLink($id: ID!) {\n    getCLICLLink(id: $id) {\n      id\n      createdAt\n      updatedAt\n      CheckListItemID\n      lane\n      CheckListID\n      CheckList {\n        id\n        createdAt\n        updatedAt\n        name\n        description\n        type\n        content\n        author\n      }\n      CheckListItem {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        type\n        connection\n        MMNodeConnection\n        investigationID\n        assignee\n        associatedPlaybooks\n        associatedCommands\n      }\n    }\n  }\n',
 'getcommands': '\n  query GetCommands($id: ID!) {\n    getCommands(id: $id) {\n      id\n      from\n      mode\n      command\n      output\n      state\n      returnCode\n      investigationId\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getcomment': '\n  query GetComment($id: ID!) {\n    getComment(id: $id) {\n      id\n      parent\n      createdAt\n      updatedAt\n      author\n      content\n      type\n      links\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getconferenceconfig': '\n  query GetConferenceConfig($id: ID!) {\n    getConferenceConfig(id: $id) {\n      id\n      url\n      userName\n      password\n      author\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getconnectorform': '\n  query GetConnectorForm($id: ID!) {\n    getConnectorForm(id: $id) {\n      id\n      createdAt\n      updatedAt\n      name\n      owner\n      connectorID\n      connector {\n        id\n        createdAt\n        updatedAt\n        category\n        name\n        owner\n        description\n        detaileddescription\n        iconPath\n        version\n        md5\n        source\n        configuration\n        commands\n        commandsType\n        script\n        scriptType\n        scriptPath\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      configData\n      commandData\n      nodeData\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n      runbooks {\n        nextToken\n      }\n    }\n  }\n',
 'getconnectors': '\n  query GetConnectors($id: ID!) {\n    getConnectors(id: $id) {\n      id\n      createdAt\n      updatedAt\n      category\n      name\n      owner\n      description\n      detaileddescription\n      iconPath\n      version\n      md5\n      source\n      configuration\n      commands\n      commandsType\n      script\n      scriptType\n      scriptPath\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n    }\n  }\n',
 'getdashboardconfig': '\n  query GetDashboardConfig($id: ID!) {\n    getDashboardConfig(id: $id) {\n      id\n      url\n      labels {\n        nextToken\n      }\n      author\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getdashboardconfiglabellink': '\n  query GetDashboardConfigLabelLink($id: ID!) {\n    getDashboardConfigLabelLink(id: $id) {\n      id\n      dashboardConfigID\n      labelID\n      dashboardConfig {\n        id\n        url\n        author\n        createdAt\n        updatedAt\n      }\n      label {\n        id\n        name\n        color\n        type\n        createdAt\n        updatedAt\n      }\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getecubesandboxexecution': '\n  query GetEcubeSandboxExecution($id: ID!) {\n    getEcubeSandboxExecution(id: $id) {\n      id\n      owner\n      output\n      outputType\n      returnCode\n      status\n      createdAt\n      updatedAt\n      E3One\n      E3Two\n      E3Three\n    }\n  }\n',
 'getepicautocomplete': '\n  query GetEpicAutoComplete($id: ID!) {\n    getEpicAutoComplete(id: $id) {\n      id\n      author\n      cliCommand\n      command\n      createdAt\n      updatedAt\n      investigationId\n      times\n    }\n  }\n',
 'getepiclicommand': '\n  query GetEpicliCommand($id: ID!) {\n    getEPICLICommand(id: $id) {\n      id\n      createdAt\n      updatedAt\n      author\n      content\n      type\n    }\n  }\n',
 'getexecutedrunbooks': '\n  query GetExecutedRunbooks($id: ID!) {\n    getExecutedRunbooks(id: $id) {\n      id\n      createdAt\n      updatedAt\n      runbookID\n      investigationId\n      output\n      outputType\n      title\n      state\n      author\n      rbVars\n      callbackUrl\n      callbackData\n      source\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      runbook {\n        id\n        name\n        description\n        content\n        author\n        commands\n        createdAt\n        updatedAt\n        RunBookConnectors\n        type\n        longSave\n        rbVars\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n    }\n  }\n',
 'getexecutedworkflowstate': '\n  query GetExecutedWorkflowState($id: ID!) {\n    getExecutedWorkflowState(id: $id) {\n      id\n      createdAt\n      updatedAt\n      name\n      state\n      output\n      type\n      allworkflowID\n      investigationID\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getgroupmember': '\n  query GetGroupMember($id: ID!) {\n    getGroupMember(id: $id) {\n      id\n      hostId\n      groupId\n      host {\n        id\n        inventoryId\n        createdAt\n        updatedAt\n        author\n        host\n        port\n        vars\n      }\n      group {\n        id\n        inventoryId\n        createdAt\n        updatedAt\n        author\n        name\n        groups\n        port\n        vars\n      }\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getguardrail': '\n  query GetGuardRail($id: ID!) {\n    getGuardRail(id: $id) {\n      id\n      timeOut\n      message\n      labels {\n        nextToken\n      }\n      author\n      active\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getguardraillabellink': '\n  query GetGuardRailLabelLink($id: ID!) {\n    getGuardRailLabelLink(id: $id) {\n      id\n      guardRailID\n      labelID\n      guardRail {\n        id\n        timeOut\n        message\n        author\n        active\n        createdAt\n        updatedAt\n      }\n      label {\n        id\n        name\n        color\n        type\n        createdAt\n        updatedAt\n      }\n      createdAt\n      updatedAt\n    }\n  }\n',
 'gethint': '\n  query GetHint($id: ID!) {\n    getHint(id: $id) {\n      id\n      investigationId\n      createdAt\n      updatedAt\n      type\n      connection\n      pastInvestigationID\n      title\n      importance\n      starrted\n      applied\n      url\n      why\n    }\n  }\n',
 'getinventory': '\n  query GetInventory($id: ID!) {\n    getInventory(id: $id) {\n      id\n      createdAt\n      updatedAt\n      author\n      name\n      all {\n        nextToken\n      }\n      groups {\n        nextToken\n      }\n      vars\n    }\n  }\n',
 'getinventorygroup': '\n  query GetInventoryGroup($id: ID!) {\n    getInventoryGroup(id: $id) {\n      id\n      inventoryId\n      createdAt\n      updatedAt\n      author\n      name\n      hosts {\n        nextToken\n      }\n      groups\n      port\n      vars\n      inventory {\n        id\n        createdAt\n        updatedAt\n        author\n        name\n        vars\n      }\n    }\n  }\n',
 'getinventoryhost': '\n  query GetInventoryHost($id: ID!) {\n    getInventoryHost(id: $id) {\n      id\n      inventoryId\n      createdAt\n      updatedAt\n      author\n      host\n      port\n      vars\n      groups {\n        nextToken\n      }\n      inventory {\n        id\n        createdAt\n        updatedAt\n        author\n        name\n        vars\n      }\n    }\n  }\n',
 'getinvestigation': '\n  query GetInvestigation($id: ID!) {\n    getInvestigation(id: $id) {\n      id\n      title\n      from\n      createdAt\n      currentState\n      HumanID\n      currentStateID\n      severity\n      priority\n      location\n      labels {\n        nextToken\n      }\n      channelId\n      investigationChannel {\n        id\n        name\n        title\n        members\n        membersState\n        createdAt\n        updatedAt\n        memberLocation\n      }\n      updatedAt\n      resolvedTime\n      resolvedComment\n      Symptoms\n      MMNodeLinks {\n        nextToken\n      }\n      CheckListInvLink {\n        nextToken\n      }\n      meetingType\n      meetingId\n    }\n  }\n',
 'getinvestigationevent': '\n  query GetInvestigationEvent($id: ID!) {\n    getInvestigationEvent(id: $id) {\n      id\n      createdAt\n      updatedAt\n      author\n      content\n      type\n      links\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getinvestigationguestuserlink': '\n  query GetInvestigationGuestUserLink($id: ID!) {\n    getInvestigationGuestUserLink(id: $id) {\n      id\n      userName\n      createdAt\n      updatedAt\n      investigationID\n      channelID\n    }\n  }\n',
 'getlabel': '\n  query GetLabel($id: ID!) {\n    getLabel(id: $id) {\n      id\n      name\n      color\n      type\n      investigations {\n        nextToken\n      }\n      userSettings {\n        nextToken\n      }\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getlabellink': '\n  query GetLabelLink($id: ID!) {\n    getLabelLink(id: $id) {\n      id\n      investigationID\n      labelID\n      label {\n        id\n        name\n        color\n        type\n        createdAt\n        updatedAt\n      }\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getleadboard': '\n  query GetLeadBoard($id: ID!) {\n    getLeadBoard(id: $id) {\n      id\n      investigationId\n      content\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getleadboardnode': '\n  query GetLeadBoardNode($id: ID!) {\n    getLeadBoardNode(id: $id) {\n      id\n      localID\n      createdAt\n      updatedAt\n      author\n      content\n      title\n      notes\n      associatedPlaybooks\n      associatedCommands\n      InvestLinks {\n        nextToken\n      }\n    }\n  }\n',
 'getmessage': '\n  query GetMessage($id: ID!) {\n    getMessage(id: $id) {\n      id\n      authorId\n      content\n      type\n      channel {\n        id\n        name\n        title\n        members\n        membersState\n        createdAt\n        updatedAt\n        memberLocation\n      }\n      messageChannelId\n      createdAt\n      updatedAt\n      author {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n    }\n  }\n',
 'getmmnodelink': '\n  query GetMmNodeLink($id: ID!) {\n    getMMNodeLink(id: $id) {\n      id\n      createdAt\n      updatedAt\n      assigned\n      state\n      content\n      author\n      investigationID\n      connectionToTask\n      LBNID\n      LeadBoardNodeId {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        notes\n        associatedPlaybooks\n        associatedCommands\n      }\n      investigationId {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getnotification': '\n  query GetNotification($id: ID!) {\n    getNotification(id: $id) {\n      id\n      userName\n      content\n      containerType\n      containerId\n      investigationId\n      isViewed\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getpin': '\n  query GetPin($id: ID!) {\n    getPin(id: $id) {\n      id\n      imageId\n      content\n      createdAt\n      updatedAt\n      author\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getprivatekey': '\n  query GetPrivateKey($id: ID!) {\n    getPrivateKey(id: $id) {\n      id\n      sshKey\n      userName\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getremotecontrol': '\n  query GetRemoteControl($id: ID!) {\n    getRemoteControl(id: $id) {\n      id\n      from\n      to\n      command\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getreportsummaryeditor': '\n  query GetReportSummaryEditor($id: ID!) {\n    getReportSummaryEditor(id: $id) {\n      id\n      investigationId\n      createdAt\n      updatedAt\n      author\n      content\n      type\n    }\n  }\n',
 'getrunbookconnectorformlink': '\n  query GetRunbookConnectorFormLink($id: ID!) {\n    getRunbookConnectorFormLink(id: $id) {\n      id\n      connectorFormId\n      runbookId\n      connectorForm {\n        id\n        createdAt\n        updatedAt\n        name\n        owner\n        connectorID\n        configData\n        commandData\n        nodeData\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      createdAt\n      updatedAt\n      runbook {\n        id\n        name\n        description\n        content\n        author\n        commands\n        createdAt\n        updatedAt\n        RunBookConnectors\n        type\n        longSave\n        rbVars\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n    }\n  }\n',
 'getschedpbs': '\n  query GetSchedPBs($id: ID!) {\n    getSchedPBs(id: $id) {\n      id\n      pbId\n      frequency\n      pbName\n      rbVars\n      scheduled\n      createdAt\n      updatedAt\n      author\n    }\n  }\n',
 'getslackchannelinfo': '\n  query GetSlackChannelInfo($id: ID!) {\n    getSlackChannelInfo(id: $id) {\n      id\n      owner\n      slackChannelId\n      slackAppId\n      slackTeamId\n      createdAt\n      updatedAt\n      slackTeam {\n        id\n        owner\n        teamId\n        teamName\n        slackAppId\n        botId\n        botToken\n        botScope\n        enterprise\n        createdAt\n        updatedAt\n      }\n      usersEnabled {\n        nextToken\n      }\n    }\n  }\n',
 'getslackenabledchannelsuserlink': '\n  query GetSlackEnabledChannelsUserLink($id: ID!) {\n    getSlackEnabledChannelsUserLink(id: $id) {\n      id\n      owner\n      slackUserId\n      slackChannelId\n      createdAt\n      updatedAt\n      slackUser {\n        id\n        userAppSyncId\n        userName\n        userId\n        userScope\n        userToken\n        slackAppId\n        slackTeamId\n        createdAt\n        updatedAt\n      }\n      slackChannel {\n        id\n        owner\n        slackChannelId\n        slackAppId\n        slackTeamId\n        createdAt\n        updatedAt\n      }\n    }\n  }\n',
 'getslackteaminfo': '\n  query GetSlackTeamInfo($id: ID!) {\n    getSlackTeamInfo(id: $id) {\n      id\n      owner\n      teamId\n      teamName\n      slackAppId\n      botId\n      botToken\n      botScope\n      enterprise\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getslackuserinfo': '\n  query GetSlackUserInfo($id: ID!) {\n    getSlackUserInfo(id: $id) {\n      id\n      userAppSyncId\n      userName\n      userId\n      userScope\n      userToken\n      slackAppId\n      slackTeamId\n      createdAt\n      updatedAt\n      userGqlInfo {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n      slackTeam {\n        id\n        owner\n        teamId\n        teamName\n        slackAppId\n        botId\n        botToken\n        botScope\n        enterprise\n        createdAt\n        updatedAt\n      }\n      channelsEnabled {\n        nextToken\n      }\n    }\n  }\n',
 'getsshtabs': '\n  query GetSshTabs($id: ID!) {\n    getSshTabs(id: $id) {\n      id\n      investigationId\n      host\n      author\n      userName\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getstash': '\n  query GetStash($id: ID!) {\n    getStash(id: $id) {\n      id\n      Key\n      Value\n      createdAt\n      updatedAt\n      author\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n    }\n  }\n',
 'getstashbykey': '\n  query GetStashByKey(\n    $Key: String\n    $sortDirection: ModelSortDirection\n    $filter: ModelStashFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    GetStashByKey(\n      Key: $Key\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        Key\n        Value\n        createdAt\n        updatedAt\n        author\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      nextToken\n    }\n  }\n',
 'getstate': '\n  query GetState($id: ID!) {\n    getState(id: $id) {\n      id\n      name\n      createdAt\n      updatedAt\n      author\n      lastState\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getsummaryinvestigation': '\n  query GetSummaryInvestigation($id: ID!) {\n    getSummaryInvestigation(id: $id) {\n      id\n      createdAt\n      updatedAt\n      resolvedTime\n      OriginalID\n      title\n      HumanID\n      Commands\n      InvestigationEvents\n      CompleteInvestigationEvents\n      Participants\n      Comments\n      Pins\n      AvailableRunbooks\n      UsedRunbooks\n      Hints\n      Symptoms\n      owner\n    }\n  }\n',
 'gettenantcustomer': '\n  query GetTenantCustomer($id: ID!) {\n    getTenantCustomer(id: $id) {\n      label\n      impactLabels\n      createdAt\n      updatedAt\n      customerName\n      email\n      phoneno\n      SLAType\n      city\n      state\n      contry\n      zipcode\n    }\n  }\n',
 'gettranscriptionrecords': '\n  query GetTranscriptionRecords($id: ID!) {\n    getTranscriptionRecords(id: $id) {\n      id\n      investigationId\n      createdAt\n      updatedAt\n      spokenBy\n      content\n    }\n  }\n',
 'getusedtogenhintalready': '\n  query GetUsedToGenHintAlready($id: ID!) {\n    getUsedToGenHintAlready(id: $id) {\n      id\n      createdAt\n      updatedAt\n      investigationId\n      commands\n      text\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getuser': '\n  query GetUser($id: ID!) {\n    getUser(id: $id) {\n      id\n      username\n      email\n      firstname\n      lastname\n      avatar\n      mood\n      name\n      role\n      status\n      timezone\n      phone\n      address\n      location\n      chatList {\n        nextToken\n      }\n      messages {\n        nextToken\n      }\n      createdAt\n      updatedAt\n      owner\n    }\n  }\n',
 'getuseractivity': '\n  query GetUserActivity($id: ID!) {\n    getUserActivity(id: $id) {\n      id\n      userID\n      status\n      investigationID\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      user {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n    }\n  }\n',
 'getusersetting': '\n  query GetUserSetting($id: ID!) {\n    getUserSetting(id: $id) {\n      id\n      userId\n      owner\n      createdAt\n      updatedAt\n      labels {\n        nextToken\n      }\n      value\n      url\n      name\n      type\n      showWelcomeNext\n      showWelcomeSkip\n      showWelcomeRemind\n      welcomeData\n    }\n  }\n',
 'getusersettinglabellink': '\n  query GetUserSettingLabelLink($id: ID!) {\n    getUserSettingLabelLink(id: $id) {\n      id\n      userSettingId\n      userSetting {\n        id\n        userId\n        owner\n        createdAt\n        updatedAt\n        value\n        url\n        name\n        type\n        showWelcomeNext\n        showWelcomeSkip\n        showWelcomeRemind\n        welcomeData\n      }\n      labelID\n      label {\n        id\n        name\n        color\n        type\n        createdAt\n        updatedAt\n      }\n      type\n      createdAt\n      updatedAt\n    }\n  }\n',
 'iblinkbyuser': '\n  query IbLinkByUser(\n    $userName: String\n    $sortDirection: ModelSortDirection\n    $filter: ModelInvestigationGuestUserLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    IbLinkByUser(\n      userName: $userName\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        userName\n        createdAt\n        updatedAt\n        investigationID\n        channelID\n      }\n      nextToken\n    }\n  }\n',
 'listallrunbookss': '\n  query ListAllRunbookss(\n    $filter: ModelAllRunbooksFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listAllRunbookss(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        name\n        description\n        content\n        author\n        commands\n        createdAt\n        updatedAt\n        RunBookConnectors\n        type\n        longSave\n        rbVars\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      nextToken\n    }\n  }\n',
 'listallworkflowss': '\n  query ListAllWorkflowss(\n    $filter: ModelAllWorkflowsFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listAllWorkflowss(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        name\n        description\n        type\n        author\n        longSave\n        rbVars\n      }\n      nextToken\n    }\n  }\n',
 'listchannellinks': '\n  query ListChannelLinks(\n    $filter: ModelChannelLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listChannelLinks(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        contactId\n        chatId\n        unread\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listchannels': '\n  query ListChannels(\n    $filter: ModelChannelFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listChannels(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        name\n        title\n        members\n        membersState\n        createdAt\n        updatedAt\n        memberLocation\n      }\n      nextToken\n    }\n  }\n',
 'listchats': '\n  query ListChats(\n    $filter: ModelChatFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listChats(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        from\n        content\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listcheatsheets': '\n  query ListCheatSheets(\n    $filter: ModelCheatSheetFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listCheatSheets(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        title\n        author\n        content\n        type\n      }\n      nextToken\n    }\n  }\n',
 'listchecklistinvlinks': '\n  query ListCheckListInvLinks(\n    $filter: ModelCheckListInvLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listCheckListInvLinks(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        investigationID\n        CheckListID\n        owner\n      }\n      nextToken\n    }\n  }\n',
 'listchecklistitems': '\n  query ListCheckListItems(\n    $filter: ModelCheckListItemFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listCheckListItems(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        type\n        connection\n        MMNodeConnection\n        investigationID\n        assignee\n        associatedPlaybooks\n        associatedCommands\n      }\n      nextToken\n    }\n  }\n',
 'listchecklists': '\n  query ListCheckLists(\n    $filter: ModelCheckListFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listCheckLists(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        name\n        description\n        type\n        content\n        author\n      }\n      nextToken\n    }\n  }\n',
 'listclicks': '\n  query ListClicks(\n    $filter: ModelClickFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listClicks(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        count\n        type\n        featureName\n        createdAt\n        updatedAt\n        readAt\n      }\n      nextToken\n    }\n  }\n',
 'listclicllinks': '\n  query ListCliclLinks(\n    $filter: ModelCLICLLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listCLICLLinks(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        CheckListItemID\n        lane\n        CheckListID\n      }\n      nextToken\n    }\n  }\n',
 'listcommandss': '\n  query ListCommandss(\n    $filter: ModelCommandsFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listCommandss(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        from\n        mode\n        command\n        output\n        state\n        returnCode\n        investigationId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listcomments': '\n  query ListComments(\n    $filter: ModelCommentFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listComments(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        parent\n        createdAt\n        updatedAt\n        author\n        content\n        type\n        links\n        investigationId\n      }\n      nextToken\n    }\n  }\n',
 'listconferenceconfigs': '\n  query ListConferenceConfigs(\n    $filter: ModelConferenceConfigFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listConferenceConfigs(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        url\n        userName\n        password\n        author\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listconnectorforms': '\n  query ListConnectorForms(\n    $filter: ModelConnectorFormFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listConnectorForms(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        name\n        owner\n        connectorID\n        configData\n        commandData\n        nodeData\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      nextToken\n    }\n  }\n',
 'listconnectorss': '\n  query ListConnectorss(\n    $filter: ModelConnectorsFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listConnectorss(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        category\n        name\n        owner\n        description\n        detaileddescription\n        iconPath\n        version\n        md5\n        source\n        configuration\n        commands\n        commandsType\n        script\n        scriptType\n        scriptPath\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      nextToken\n    }\n  }\n',
 'listdashboardconfiglabellinks': '\n  query ListDashboardConfigLabelLinks(\n    $filter: ModelDashboardConfigLabelLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listDashboardConfigLabelLinks(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        dashboardConfigID\n        labelID\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listdashboardconfigs': '\n  query ListDashboardConfigs(\n    $filter: ModelDashboardConfigFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listDashboardConfigs(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        url\n        author\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listecubesandboxexecutions': '\n  query ListEcubeSandboxExecutions(\n    $filter: ModelEcubeSandboxExecutionFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listEcubeSandboxExecutions(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        owner\n        output\n        outputType\n        returnCode\n        status\n        createdAt\n        updatedAt\n        E3One\n        E3Two\n        E3Three\n      }\n      nextToken\n    }\n  }\n',
 'listepicautocompletes': '\n  query ListEpicAutoCompletes(\n    $filter: ModelepicAutoCompleteFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listEpicAutoCompletes(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        author\n        cliCommand\n        command\n        createdAt\n        updatedAt\n        investigationId\n        times\n      }\n      nextToken\n    }\n  }\n',
 'listepiclicommands': '\n  query ListEpicliCommands(\n    $filter: ModelEPICLICommandFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listEPICLICommands(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        author\n        content\n        type\n      }\n      nextToken\n    }\n  }\n',
 'listexecutedrunbookss': '\n  query ListExecutedRunbookss(\n    $filter: ModelExecutedRunbooksFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listExecutedRunbookss(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        runbookID\n        investigationId\n        output\n        outputType\n        title\n        state\n        author\n        rbVars\n        callbackUrl\n        callbackData\n        source\n      }\n      nextToken\n    }\n  }\n',
 'listexecutedworkflowstates': '\n  query ListExecutedWorkflowStates(\n    $filter: ModelExecutedWorkflowStateFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listExecutedWorkflowStates(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        name\n        state\n        output\n        type\n        allworkflowID\n        investigationID\n      }\n      nextToken\n    }\n  }\n',
 'listgroupmembers': '\n  query ListGroupMembers(\n    $filter: ModelGroupMemberFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listGroupMembers(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        hostId\n        groupId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listguardraillabellinks': '\n  query ListGuardRailLabelLinks(\n    $filter: ModelGuardRailLabelLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listGuardRailLabelLinks(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        guardRailID\n        labelID\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listguardrails': '\n  query ListGuardRails(\n    $filter: ModelGuardRailFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listGuardRails(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        timeOut\n        message\n        author\n        active\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listhints': '\n  query ListHints(\n    $filter: ModelHintFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listHints(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        investigationId\n        createdAt\n        updatedAt\n        type\n        connection\n        pastInvestigationID\n        title\n        importance\n        starrted\n        applied\n        url\n        why\n      }\n      nextToken\n    }\n  }\n',
 'listinventorygroups': '\n  query ListInventoryGroups(\n    $filter: ModelInventoryGroupFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listInventoryGroups(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        inventoryId\n        createdAt\n        updatedAt\n        author\n        name\n        groups\n        port\n        vars\n      }\n      nextToken\n    }\n  }\n',
 'listinventoryhosts': '\n  query ListInventoryHosts(\n    $filter: ModelInventoryHostFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listInventoryHosts(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        inventoryId\n        createdAt\n        updatedAt\n        author\n        host\n        port\n        vars\n      }\n      nextToken\n    }\n  }\n',
 'listinventorys': '\n  query ListInventorys(\n    $filter: ModelInventoryFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listInventorys(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        author\n        name\n        vars\n      }\n      nextToken\n    }\n  }\n',
 'listinvestigationevents': '\n  query ListInvestigationEvents(\n    $filter: ModelInvestigationEventFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listInvestigationEvents(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        author\n        content\n        type\n        links\n        investigationId\n      }\n      nextToken\n    }\n  }\n',
 'listinvestigationguestuserlinks': '\n  query ListInvestigationGuestUserLinks(\n    $filter: ModelInvestigationGuestUserLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listInvestigationGuestUserLinks(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        userName\n        createdAt\n        updatedAt\n        investigationID\n        channelID\n      }\n      nextToken\n    }\n  }\n',
 'listinvestigations': '\n  query ListInvestigations(\n    $filter: ModelInvestigationFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listInvestigations(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      nextToken\n    }\n  }\n',
 'listlabellinks': '\n  query ListLabelLinks(\n    $filter: ModelLabelLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listLabelLinks(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        investigationID\n        labelID\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listlabels': '\n  query ListLabels(\n    $filter: ModelLabelFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listLabels(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        name\n        color\n        type\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listleadboardnodes': '\n  query ListLeadBoardNodes(\n    $filter: ModelLeadBoardNodeFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listLeadBoardNodes(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        notes\n        associatedPlaybooks\n        associatedCommands\n      }\n      nextToken\n    }\n  }\n',
 'listleadboards': '\n  query ListLeadBoards(\n    $filter: ModelLeadBoardFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listLeadBoards(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        investigationId\n        content\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listmessages': '\n  query ListMessages(\n    $filter: ModelMessageFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listMessages(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        authorId\n        content\n        type\n        messageChannelId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listmmnodelinks': '\n  query ListMmNodeLinks(\n    $filter: ModelMMNodeLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listMMNodeLinks(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        assigned\n        state\n        content\n        author\n        investigationID\n        connectionToTask\n        LBNID\n      }\n      nextToken\n    }\n  }\n',
 'listnotifications': '\n  query ListNotifications(\n    $filter: ModelNotificationFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listNotifications(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        userName\n        content\n        containerType\n        containerId\n        investigationId\n        isViewed\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listpins': '\n  query ListPins(\n    $filter: ModelPinFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listPins(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        imageId\n        content\n        createdAt\n        updatedAt\n        author\n        investigationId\n      }\n      nextToken\n    }\n  }\n',
 'listprivatekeys': '\n  query ListPrivateKeys(\n    $filter: ModelPrivateKeyFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listPrivateKeys(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        sshKey\n        userName\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listremotecontrols': '\n  query ListRemoteControls(\n    $filter: ModelremoteControlFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listRemoteControls(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        from\n        to\n        command\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listreportsummaryeditors': '\n  query ListReportSummaryEditors(\n    $filter: ModelReportSummaryEditorFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listReportSummaryEditors(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        investigationId\n        createdAt\n        updatedAt\n        author\n        content\n        type\n      }\n      nextToken\n    }\n  }\n',
 'listrunbookconnectorformlinks': '\n  query ListRunbookConnectorFormLinks(\n    $filter: ModelRunbookConnectorFormLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listRunbookConnectorFormLinks(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        connectorFormId\n        runbookId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listschedpbss': '\n  query ListSchedPBss(\n    $filter: ModelSchedPBsFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listSchedPBss(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        pbId\n        frequency\n        pbName\n        rbVars\n        scheduled\n        createdAt\n        updatedAt\n        author\n      }\n      nextToken\n    }\n  }\n',
 'listslackchannelinfos': '\n  query ListSlackChannelInfos(\n    $filter: ModelSlackChannelInfoFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listSlackChannelInfos(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        owner\n        slackChannelId\n        slackAppId\n        slackTeamId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listslackenabledchannelsuserlinks': '\n  query ListSlackEnabledChannelsUserLinks(\n    $filter: ModelSlackEnabledChannelsUserLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listSlackEnabledChannelsUserLinks(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        owner\n        slackUserId\n        slackChannelId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listslackteaminfos': '\n  query ListSlackTeamInfos(\n    $filter: ModelSlackTeamInfoFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listSlackTeamInfos(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        owner\n        teamId\n        teamName\n        slackAppId\n        botId\n        botToken\n        botScope\n        enterprise\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listslackuserinfos': '\n  query ListSlackUserInfos(\n    $filter: ModelSlackUserInfoFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listSlackUserInfos(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        userAppSyncId\n        userName\n        userId\n        userScope\n        userToken\n        slackAppId\n        slackTeamId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listsshtabss': '\n  query ListSshTabss(\n    $filter: ModelSshTabsFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listSshTabss(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        investigationId\n        host\n        author\n        userName\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'liststashs': '\n  query ListStashs(\n    $filter: ModelStashFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listStashs(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        Key\n        Value\n        createdAt\n        updatedAt\n        author\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      nextToken\n    }\n  }\n',
 'liststates': '\n  query ListStates(\n    $filter: ModelStateFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listStates(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        name\n        createdAt\n        updatedAt\n        author\n        lastState\n        investigationId\n      }\n      nextToken\n    }\n  }\n',
 'listsummaryinvestigations': '\n  query ListSummaryInvestigations(\n    $filter: ModelSummaryInvestigationFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listSummaryInvestigations(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        resolvedTime\n        OriginalID\n        title\n        HumanID\n        Commands\n        InvestigationEvents\n        CompleteInvestigationEvents\n        Participants\n        Comments\n        Pins\n        AvailableRunbooks\n        UsedRunbooks\n        Hints\n        Symptoms\n        owner\n      }\n      nextToken\n    }\n  }\n',
 'listtenantcustomers': '\n  query ListTenantCustomers(\n    $filter: ModelTenantCustomerFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listTenantCustomers(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        label\n        impactLabels\n        createdAt\n        updatedAt\n        customerName\n        email\n        phoneno\n        SLAType\n        city\n        state\n        contry\n        zipcode\n      }\n      nextToken\n    }\n  }\n',
 'listtranscriptionrecordss': '\n  query ListTranscriptionRecordss(\n    $filter: ModelTranscriptionRecordsFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listTranscriptionRecordss(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        investigationId\n        createdAt\n        updatedAt\n        spokenBy\n        content\n      }\n      nextToken\n    }\n  }\n',
 'listusedtogenhintalreadys': '\n  query ListUsedToGenHintAlreadys(\n    $filter: ModelUsedToGenHintAlreadyFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listUsedToGenHintAlreadys(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        investigationId\n        commands\n        text\n      }\n      nextToken\n    }\n  }\n',
 'listuseractivitys': '\n  query ListUserActivitys(\n    $filter: ModelUserActivityFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listUserActivitys(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        userID\n        status\n        investigationID\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listusers': '\n  query ListUsers(\n    $filter: ModelUserFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listUsers(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n      nextToken\n    }\n  }\n',
 'listusersettinglabellinks': '\n  query ListUserSettingLabelLinks(\n    $filter: ModelUserSettingLabelLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listUserSettingLabelLinks(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        userSettingId\n        labelID\n        type\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listusersettings': '\n  query ListUserSettings(\n    $filter: ModelUserSettingFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listUserSettings(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        userId\n        owner\n        createdAt\n        updatedAt\n        value\n        url\n        name\n        type\n        showWelcomeNext\n        showWelcomeSkip\n        showWelcomeRemind\n        welcomeData\n      }\n      nextToken\n    }\n  }\n',
 'msgsbycreatedat': '\n  query MsgsByCreatedAt(\n    $messageChannelId: ID\n    $createdAt: ModelStringKeyConditionInput\n    $sortDirection: ModelSortDirection\n    $filter: ModelMessageFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    msgsByCreatedAt(\n      messageChannelId: $messageChannelId\n      createdAt: $createdAt\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        authorId\n        content\n        type\n        messageChannelId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'searchallrunbookss': '\n  query SearchAllRunbookss(\n    $filter: SearchableAllRunbooksFilterInput\n    $sort: SearchableAllRunbooksSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchAllRunbookss(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        name\n        description\n        content\n        author\n        commands\n        createdAt\n        updatedAt\n        RunBookConnectors\n        type\n        longSave\n        rbVars\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchcheatsheets': '\n  query SearchCheatSheets(\n    $filter: SearchableCheatSheetFilterInput\n    $sort: SearchableCheatSheetSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchCheatSheets(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        title\n        author\n        content\n        type\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchchecklistitems': '\n  query SearchCheckListItems(\n    $filter: SearchableCheckListItemFilterInput\n    $sort: SearchableCheckListItemSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchCheckListItems(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        type\n        connection\n        MMNodeConnection\n        investigationID\n        assignee\n        associatedPlaybooks\n        associatedCommands\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchchecklists': '\n  query SearchCheckLists(\n    $filter: SearchableCheckListFilterInput\n    $sort: SearchableCheckListSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchCheckLists(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        name\n        description\n        type\n        content\n        author\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchepicautocompletes': '\n  query SearchEpicAutoCompletes(\n    $filter: SearchableepicAutoCompleteFilterInput\n    $sort: SearchableepicAutoCompleteSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchEpicAutoCompletes(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        author\n        cliCommand\n        command\n        createdAt\n        updatedAt\n        investigationId\n        times\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchinvestigationguestuserlinks': '\n  query SearchInvestigationGuestUserLinks(\n    $filter: SearchableInvestigationGuestUserLinkFilterInput\n    $sort: SearchableInvestigationGuestUserLinkSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchInvestigationGuestUserLinks(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        userName\n        createdAt\n        updatedAt\n        investigationID\n        channelID\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchleadboardnodes': '\n  query SearchLeadBoardNodes(\n    $filter: SearchableLeadBoardNodeFilterInput\n    $sort: SearchableLeadBoardNodeSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchLeadBoardNodes(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        notes\n        associatedPlaybooks\n        associatedCommands\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchreportsummaryeditors': '\n  query SearchReportSummaryEditors(\n    $filter: SearchableReportSummaryEditorFilterInput\n    $sort: SearchableReportSummaryEditorSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchReportSummaryEditors(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        investigationId\n        createdAt\n        updatedAt\n        author\n        content\n        type\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchstashs': '\n  query SearchStashs(\n    $filter: SearchableStashFilterInput\n    $sort: SearchableStashSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchStashs(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        Key\n        Value\n        createdAt\n        updatedAt\n        author\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchsummaryinvestigations': '\n  query SearchSummaryInvestigations(\n    $filter: SearchableSummaryInvestigationFilterInput\n    $sort: SearchableSummaryInvestigationSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchSummaryInvestigations(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        resolvedTime\n        OriginalID\n        title\n        HumanID\n        Commands\n        InvestigationEvents\n        CompleteInvestigationEvents\n        Participants\n        Comments\n        Pins\n        AvailableRunbooks\n        UsedRunbooks\n        Hints\n        Symptoms\n        owner\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchtenantcustomers': '\n  query SearchTenantCustomers(\n    $filter: SearchableTenantCustomerFilterInput\n    $sort: SearchableTenantCustomerSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchTenantCustomers(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        label\n        impactLabels\n        createdAt\n        updatedAt\n        customerName\n        email\n        phoneno\n        SLAType\n        city\n        state\n        contry\n        zipcode\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchtranscriptionrecordss': '\n  query SearchTranscriptionRecordss(\n    $filter: SearchableTranscriptionRecordsFilterInput\n    $sort: SearchableTranscriptionRecordsSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchTranscriptionRecordss(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        investigationId\n        createdAt\n        updatedAt\n        spokenBy\n        content\n      }\n      nextToken\n      total\n    }\n  }\n',
 'slackinfoforappsyncuser': '\n  query SlackInfoForAppSyncUser(\n    $userAppSyncId: ID\n    $sortDirection: ModelSortDirection\n    $filter: ModelSlackUserInfoFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    SlackInfoForAppSyncUser(\n      userAppSyncId: $userAppSyncId\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        userAppSyncId\n        userName\n        userId\n        userScope\n        userToken\n        slackAppId\n        slackTeamId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'slackteaminfoforbot': '\n  query SlackTeamInfoForBot(\n    $botId: String\n    $sortDirection: ModelSortDirection\n    $filter: ModelSlackTeamInfoFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    SlackTeamInfoForBot(\n      botId: $botId\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        owner\n        teamId\n        teamName\n        slackAppId\n        botId\n        botToken\n        botScope\n        enterprise\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'slackuserinfo': '\n  query SlackUserInfo(\n    $userId: ID\n    $sortDirection: ModelSortDirection\n    $filter: ModelSlackUserInfoFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    SlackUserInfo(\n      userId: $userId\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        userAppSyncId\n        userName\n        userId\n        userScope\n        userToken\n        slackAppId\n        slackTeamId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'statebyibid': '\n  query StateByIbid(\n    $investigationId: ID\n    $sortDirection: ModelSortDirection\n    $filter: ModelStateFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    stateByIBID(\n      investigationId: $investigationId\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        name\n        createdAt\n        updatedAt\n        author\n        lastState\n        investigationId\n      }\n      nextToken\n    }\n  }\n',
 'trbyinvestigationid': '\n  query TrByInvestigationId(\n    $investigationId: ID\n    $sortDirection: ModelSortDirection\n    $filter: ModelTranscriptionRecordsFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    trByInvestigationId(\n      investigationId: $investigationId\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        investigationId\n        createdAt\n        updatedAt\n        spokenBy\n        content\n      }\n      nextToken\n    }\n  }\n',
 'userbyemail': '\n  query UserByEmail(\n    $email: String\n    $sortDirection: ModelSortDirection\n    $filter: ModelUserFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    UserByEmail(\n      email: $email\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n      nextToken\n    }\n  }\n',
 'usersettingbyuser': '\n  query UserSettingByUser(\n    $userId: ID\n    $sortDirection: ModelSortDirection\n    $filter: ModelUserSettingFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    userSettingByUser(\n      userId: $userId\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        userId\n        owner\n        createdAt\n        updatedAt\n        value\n        url\n        name\n        type\n        showWelcomeNext\n        showWelcomeSkip\n        showWelcomeRemind\n        welcomeData\n      }\n      nextToken\n    }\n  }\n'}
